pub enum CommandWorkspaceProviderSetupError {
EmptyCommand,
ReservedEnvironmentKey(String),
InvalidEnvironmentEntry(String),
}Expand description
Why a command-backed workspace provider could not be built.
Variants
EmptyCommand
The materializer command was empty.
ReservedEnvironmentKey(String)
A protected environment value was supplied by the operator.
InvalidEnvironmentEntry(String)
An environment key or value cannot be passed to a process.