PickerMode

Enum PickerMode 

pub enum PickerMode {
    CapableFirst,
    EfficientFirst,
}
Which tier to default to when the scorer is not confident.

Variants



CapableFirst

Default to capable unless the scorer confidently picks efficient.



EfficientFirst

Default to efficient unless the scorer confidently picks capable.

Implementations

Source

impl PickerMode

pub fn default_tier(self) -> Tier

Tier a turn routes to when the scorer is not confident enough to pick.