pub struct PlanExecute { /* private fields */ }Expand description
Routes planning turns to the runtime capable model, then latches execution to the runtime efficient model after the first recorded mutation.
Implementations
Sourceimpl PlanExecute
impl PlanExecute
Sourcepub fn new(config: PlanExecuteConfig) -> Result<Self>
pub fn new(config: PlanExecuteConfig) -> Result<Self>
Creates a plan/execute router.
Returns an error when either configured prompt is blank.