pub enum PickerMode {
CapableFirst,
EfficientFirst,
}Expand description
Which tier to default to when the scorer is not confident.
Variants
CapableFirst
Default to capable unless the scorer confidently picks efficient.
EfficientFirst
Default to efficient unless the scorer confidently picks capable.
Implementations
Sourceimpl PickerMode
impl PickerMode
Sourcepub fn default_tier(self) -> Tier
pub fn default_tier(self) -> Tier
Tier a turn routes to when the scorer is not confident enough to pick.