pub struct LlmTaskClassifier { /* private fields */ }Expand description
Routes requests through a capability, escalation, or custom classifier mode.
Implementations
Sourceimpl LlmTaskClassifier
impl LlmTaskClassifier
Sourcepub fn new(config: LlmClassifierConfig) -> Result<Self>
pub fn new(config: LlmClassifierConfig) -> Result<Self>
Builds the classifier mode described by config.
Errors
Returns an error when the selected mode’s targets, contract, policy, or runtime settings are invalid.