PlanExecute

Struct PlanExecute 

pub struct PlanExecute { /* private fields */ }
Routes planning turns to the runtime capable model, then latches execution to the runtime efficient model after the first recorded mutation.

Implementations

Source

impl PlanExecute

pub fn new(config: PlanExecuteConfig) -> Result<Self>

Creates a plan/execute router.

Returns an error when either configured prompt is blank.