pub struct PlanExecute { /* private fields */ }Expand description
Routes planning turns to a capable model and all turns after the first edit to an efficient model while preserving the caller’s full trajectory.
Implementations
Sourceimpl PlanExecute
impl PlanExecute